@@ -1,5 +1,5 @@
 /* GStreamer Adaptive Multi-Rate Wide-Band (AMR-WB) plugin
- * Copyright (C) 2006 Edgard Lima <edgard.lima@gmail.com>
+ * Copyright (C) 2006 Edgard Lima <edgard.lima@indt.org.br>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_AMRWBDEC_H__
@@ -23,8 +23,13 @@
 #include <gst/gst.h>
 #include <gst/audio/gstaudiodecoder.h>
 
+#ifdef HAVE_OPENCORE_AMRWB_0_1_3_OR_LATER
 #include <opencore-amrwb/dec_if.h>
 #include <opencore-amrwb/if_rom.h>
+#else
+#include <dec_if.h>
+#include <if_rom.h>
+#endif
 
 G_BEGIN_DECLS
 
