@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,7 +40,8 @@ enum
 enum
 {
   PROP_0,
-  PROP_LOCATION
+  PROP_LOCATION,
+  PROP_LAST
 };
 
 static GstStaticPadTemplate gst_pnm_src_template =
@@ -58,8 +59,6 @@ static void gst_pnm_src_uri_handler_init (gpointer g_iface,
 #define gst_pnm_src_parent_class parent_class
 G_DEFINE_TYPE_WITH_CODE (GstPNMSrc, gst_pnm_src, GST_TYPE_PUSH_SRC,
     G_IMPLEMENT_INTERFACE (GST_TYPE_URI_HANDLER, gst_pnm_src_uri_handler_init));
-GST_ELEMENT_REGISTER_DEFINE (pnmsrc, "pnmsrc",
-    GST_RANK_MARGINAL, GST_TYPE_PNM_SRC);
 
 static void gst_pnm_src_finalize (GObject * object);
 
@@ -92,8 +91,8 @@ gst_pnm_src_class_init (GstPNMSrcClass * klass)
           DEFAULT_LOCATION, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_pnm_src_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_pnm_src_template));
 
   gst_element_class_set_static_metadata (gstelement_class,
       "PNM packet receiver", "Source/Network",
@@ -112,6 +111,13 @@ gst_pnm_src_init (GstPNMSrc * pnmsrc)
   pnmsrc->location = g_strdup (DEFAULT_LOCATION);
 }
 
+gboolean
+gst_pnm_src_plugin_init (GstPlugin * plugin)
+{
+  return gst_element_register (plugin, "pnmsrc",
+      GST_RANK_MARGINAL, GST_TYPE_PNM_SRC);
+}
+
 static void
 gst_pnm_src_finalize (GObject * object)
 {
